@@ -50,7 +50,7 @@ class PersistenceSystem(ABC):
         """
         pass
 
-    @abstractmethod
+    #@abstractmethod
     def write(self, g: Graph, rdf_format, leading_comments, *args):
         """
         Persists the given Graph in the form implemented by this Persistence System
@@ -206,6 +206,9 @@ class File(PersistenceSystem):
             file_path = self.directory / f"{filename}.{rdf_format}"
 
         s = self.generate_string(g, rdf_format, leading_comments)
+        # remove extra line at end of file
+        if s[-1] == '\n' and s[-2] == '\n':
+            s = s[:-1]
 
         with file_path.open("w", encoding="utf-8") as f:
             f.write(s)
@@ -444,15 +447,19 @@ class SOP(PersistenceSystem):
         self.client = None
         self.local = True if location.startswith("http://localhost") else False
 
-    def write(self, g: Graph, graph_iri):
+    def write(self, g: Graph, graph_iri, leading_comments=None):
         if not (graph_iri.startswith("http") or graph_iri.startswith("urn")):
             raise ValueError(
                 f"The value you supplied for graph_iri ({graph_iri}) is not valid"
             )
         if not self.client:
             self._create_client()
-
-        content = g.serialize(format="turtle", encoding="utf-8")
+        content = ''
+        if leading_comments:
+            content = ''.join(leading_comments)
+        content = (bytes(content, encoding="utf-8") + bytes(g.serialize(), encoding="utf-8"))
+#        content += str(g.serialize(format="turtle", encoding="utf-8"))
+#        content = bytes(content,encoding="utf-8")
         headers = {}
         if self.local:
             headers["Cookie"] = "username=Administrator"
